==> haskell-resolv-0.1.1.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-resolv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resolv
version: 0.1.1.1
id: resolv-0.1.1.1-JE0F05VqIRvJXa0qbVDgHe
key: resolv-0.1.1.1-JE0F05VqIRvJXa0qbVDgHe
license: GPL-3.0-only
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Domain Name Service (DNS) lookup via the libresolv standard library routines
description:
    This package implements an API for accessing
    the [Domain Name Service (DNS)](https://tools.ietf.org/html/rfc1035)
    resolver service via the standard @libresolv@ system library (whose
    API is often available directly via the standard @libc@ C library) on
    Unix systems.
    .
    This package also includes support for decoding message record types
    as defined in the following RFCs:
    .
    - [RFC 1035](https://tools.ietf.org/html/rfc1035): Domain Names - Implementation And Specification
    - [RFC 1183](https://tools.ietf.org/html/rfc1183): New DNS RR Definitions
    - [RFC 2782](https://tools.ietf.org/html/rfc2782): A DNS RR for specifying the location of services (DNS SRV)
    - [RFC 2915](https://tools.ietf.org/html/rfc2915): The Naming Authority Pointer (NAPTR) DNS Resource Record
    - [RFC 3596](https://tools.ietf.org/html/rfc3596): DNS Extensions to Support IP Version 6
    - [RFC 4034](https://tools.ietf.org/html/rfc4034): Resource Records for the DNS Security Extensions
    - [RFC 4255](https://tools.ietf.org/html/rfc4255): Using DNS to Securely Publish Secure Shell (SSH) Key Fingerprints
    - [RFC 4408](https://tools.ietf.org/html/rfc4408): Sender Policy Framework (SPF) for Authorizing Use of Domains in E-Mail, Version 1
    - [RFC 5155](https://tools.ietf.org/html/rfc5155): DNS Security (DNSSEC) Hashed Authenticated Denial of Existence
    - [RFC 6844](https://tools.ietf.org/html/rfc6844): DNS Certification Authority Authorization (CAA) Resource Record
    - [RFC 6891](https://tools.ietf.org/html/rfc6891): Extension Mechanisms for DNS (EDNS(0))
    - [RFC 7553](https://tools.ietf.org/html/rfc7553): The Uniform Resource Identifier (URI) DNS Resource Record
category: Network
abi: 55e5d5b27af6e24c44b000371365ecde
exposed: True
exposed-modules:
    Network.DNS
hidden-modules: Network.DNS.Message Network.DNS.FFI Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/resolv-0.1.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/resolv-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/resolv-0.1.1.1
hs-libraries: HSresolv-0.1.1.1-JE0F05VqIRvJXa0qbVDgHe
extra-libraries:
    resolv
depends:
    base-4.11.1.0 base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-resolv/html/resolv.haddock
haddock-html: /usr/share/doc/haskell-resolv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resolv-0.1.1.1-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-resolv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resolv
version: 0.1.1.1
id: resolv-0.1.1.1-F3KQTQkIJ8EHTF6KWEEwzf
key: resolv-0.1.1.1-F3KQTQkIJ8EHTF6KWEEwzf
license: GPL-3.0-only
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
synopsis: Domain Name Service (DNS) lookup via the libresolv standard library routines
description:
    This package implements an API for accessing
    the [Domain Name Service (DNS)](https://tools.ietf.org/html/rfc1035)
    resolver service via the standard @libresolv@ system library (whose
    API is often available directly via the standard @libc@ C library) on
    Unix systems.
    .
    This package also includes support for decoding message record types
    as defined in the following RFCs:
    .
    - [RFC 1035](https://tools.ietf.org/html/rfc1035): Domain Names - Implementation And Specification
    - [RFC 1183](https://tools.ietf.org/html/rfc1183): New DNS RR Definitions
    - [RFC 2782](https://tools.ietf.org/html/rfc2782): A DNS RR for specifying the location of services (DNS SRV)
    - [RFC 2915](https://tools.ietf.org/html/rfc2915): The Naming Authority Pointer (NAPTR) DNS Resource Record
    - [RFC 3596](https://tools.ietf.org/html/rfc3596): DNS Extensions to Support IP Version 6
    - [RFC 4034](https://tools.ietf.org/html/rfc4034): Resource Records for the DNS Security Extensions
    - [RFC 4255](https://tools.ietf.org/html/rfc4255): Using DNS to Securely Publish Secure Shell (SSH) Key Fingerprints
    - [RFC 4408](https://tools.ietf.org/html/rfc4408): Sender Policy Framework (SPF) for Authorizing Use of Domains in E-Mail, Version 1
    - [RFC 5155](https://tools.ietf.org/html/rfc5155): DNS Security (DNSSEC) Hashed Authenticated Denial of Existence
    - [RFC 6844](https://tools.ietf.org/html/rfc6844): DNS Certification Authority Authorization (CAA) Resource Record
    - [RFC 6891](https://tools.ietf.org/html/rfc6891): Extension Mechanisms for DNS (EDNS(0))
    - [RFC 7553](https://tools.ietf.org/html/rfc7553): The Uniform Resource Identifier (URI) DNS Resource Record
category: Network
abi: 08d8f937c99ab34c8ca33e37916dda18
exposed: True
exposed-modules:
    Network.DNS
hidden-modules: Network.DNS.Message Network.DNS.FFI Compat
import-dirs: /usr/lib/ghc-8.6.1/site-local/resolv-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/resolv-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/resolv-0.1.1.1
hs-libraries: HSresolv-0.1.1.1-F3KQTQkIJ8EHTF6KWEEwzf
extra-libraries:
    resolv
depends:
    base-4.12.0.0 base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    binary-0.8.6.0 bytestring-0.10.8.2 containers-0.6.0.1
haddock-interfaces: /usr/share/doc/haskell-resolv/html/resolv.haddock
haddock-html: /usr/share/doc/haskell-resolv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
